/**
 * OW2 Util
 * Copyright (C) 2008 SERLI
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: FileArchiveImpl.java
 * --------------------------------------------------------------------------
 */

package org.ow2.util.archive.impl;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.util.Iterator;

import org.ow2.util.archive.api.ArchiveException;
import org.ow2.util.archive.api.IArchiveMetadata;
import org.ow2.util.archive.api.IFileArchive;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.url.URLUtils;

/**
 * An implementation for the IFileArchive class.
 * @author mleduque
 */
public class FileArchiveImpl implements IFileArchive {

    /**
     * Logger.
     */
    private static final Log logger = LogFactory.getLog(FileArchiveImpl.class);

    /**
     * The file of the archive.
     */
    private File file = null;

    /**
     * Cached URL of this archive.
     */
    private URL url = null;

    /**
     * Constructor with no arguments.
     */
    public FileArchiveImpl() {
    }

    /**
     * Constructs a file archive wit the given file.
     * @param file the given file
     */
    public FileArchiveImpl(final File file) {
        setFile(file);
    }

    /**
     * {@inheritDoc}
     */
    public void setFile(final File file) {
        // TODO, Shouldn't we allow this to change only once ???
        try {
            this.file = file.getCanonicalFile();
        } catch (IOException e) {
            logger.debug("File ''{0}'' cannot be canonicalized, use it as is", file);
            this.file = file;
        }
        this.url = URLUtils.fileToURL(this.file);
    }

    /**
     * {@inheritDoc}
     */
    public File getFile() {
        return this.file;
    }

    /**
     * {@inheritDoc}
     */
    public boolean close() {
        return true;
    }

    /**
     * {@inheritDoc}
     */
    public IArchiveMetadata getMetadata() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public String getName() {
        return file.getPath();
    }

    /**
     * {@inheritDoc}
     */
    public URL getResource(final String resourceName) throws ArchiveException {
        throw new ArchiveException("No resources inside this file");
    }

    /**
     * {@inheritDoc}
     */
    public Iterator<URL> getResources() throws ArchiveException {
        throw new ArchiveException("No resources inside this file");
    }

    /**
     * {@inheritDoc}
     */
    public Iterator<URL> getResources(final String resourceName)
            throws ArchiveException {
        throw new ArchiveException("No resources inside this file");
    }

    /**
     * {@inheritDoc}
     */
    public URL getURL() throws ArchiveException {
        return this.url;
    }

    /**
     * {@inheritDoc}
     */
    public Iterator<String> getEntries() throws ArchiveException {
        return null;
    }

    /**
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return getName();
    }
}
